@@ -6,7 +6,7 @@ from syst3m.v1.classes.system import User, Group
 from syst3m.v1.classes.color import color, symbol
 from syst3m.v1.classes.defaults import defaults
 from syst3m.v1.classes.env import env
-from syst3m.v1.classes import utils, console
+from syst3m.v1.classes import utils, console, objects
 #from syst3m.v1.classes.screen import screen
 #from syst3m.v1.classes.keyboard import keyboard
 #from syst3m.v1.classes.mouse import mouse
\ No newline at end of file
