@@ -36,14 +36,14 @@ class Defaults(object):
 		# overwrite.
 		overwrite=False,
 	):
-		if sudo or "--sudo" in sys.argv: sudo = "sudo "
+		if sudo or cl1.argument_present("--sudo"): sudo = "sudo "
 		else: sudo = ""
 		present = "--create-alias" in sys.argv and cl1.get_argument("--create-alias") == alias
 		base = f"/usr/local/bin"
 		if not os.path.exists(base):
 			base = f"/usr/bin/"
 		path = f"{base}/{alias}"
-		if overwrite or present or not os.path.exists(path):
+		if cl1.argument_present("--force") or cl1.argument_present("--forced") or overwrite or present or not os.path.exists(path):
 			#file = f"""package={executable}/\nargs=""\nfor var in "$@" ; do\n   	if [ "$args" == "" ] ; then\n   		args=$var\n   	else\n   		args=$args" "$var\n   	fi\ndone\npython3 $package $args\n"""
 			file = f"""#!/usr/bin/env python3\nimport os, sys\npackage="{executable}"\nsys.argv.pop(0)\narguments = sys.argv\ns = ""\nfor i in arguments:\n	if s == "": \n		if " " in i: s = "'"+i+"'"\n		else: s = i\n	else: \n		if " " in i: s += " '"+i+"'"\n		else: s += " "+i\nos.system("python3 "+package+" "+s)"""
 			os.system(f"{sudo}touch {path}")
@@ -63,7 +63,7 @@ class Defaults(object):
 	def get_source_path(self, path, back=1):
 		return Formats.FilePath(path).base(back=back)
 	def get_log_level(self):
-		return cl1.get_argument("--log-level", empty=0)
+		return cl1.get_argument("--log-level", required=False, empty=0)
 
 # initialized classes.
 defaults = Defaults()
\ No newline at end of file
